@@ -82,6 +82,8 @@ gboolean lightdm_greeter_get_hide_users_hint (LightDMGreeter *greeter);
 
 gboolean lightdm_greeter_get_show_manual_login_hint (LightDMGreeter *greeter);
 
+gboolean lightdm_greeter_get_show_remote_login_hint (LightDMGreeter *greeter);
+
 gboolean lightdm_greeter_get_lock_hint (LightDMGreeter *greeter);
 
 gboolean lightdm_greeter_get_has_guest_account_hint (LightDMGreeter *greeter);
@@ -98,12 +100,14 @@ gint lightdm_greeter_get_autologin_timeout_hint (LightDMGreeter *greeter);
 
 void lightdm_greeter_cancel_autologin (LightDMGreeter *greeter);
 
-void lightdm_greeter_authenticate (LightDMGreeter *greeter, const char *username);
+void lightdm_greeter_authenticate (LightDMGreeter *greeter, const gchar *username);
 
 void lightdm_greeter_authenticate_as_guest (LightDMGreeter *greeter);
 
 void lightdm_greeter_authenticate_autologin (LightDMGreeter *greeter);
 
+void lightdm_greeter_authenticate_remote (LightDMGreeter *greeter, const gchar *session, const gchar *username);
+
 void lightdm_greeter_respond (LightDMGreeter *greeter, const gchar *response);
 
 void lightdm_greeter_cancel_authentication (LightDMGreeter *greeter);
