@@ -125,6 +125,12 @@ void Greeter::authenticateAutologin()
     lightdm_greeter_authenticate_autologin(d->ldmGreeter);
 }
 
+void Greeter::authenticateRemote(const QString &session, const QString &username)
+{
+    Q_D(Greeter);
+    lightdm_greeter_authenticate_remote(d->ldmGreeter, session.toLocal8Bit().data(), username.toLocal8Bit().data());
+}
+
 void Greeter::respond(const QString &response)
 {
     Q_D(Greeter);
@@ -192,6 +198,12 @@ bool Greeter::showManualLoginHint() const
     return lightdm_greeter_get_show_manual_login_hint(d->ldmGreeter);
 }
 
+bool Greeter::showRemoteLoginHint() const
+{
+    Q_D(const Greeter);
+    return lightdm_greeter_get_show_remote_login_hint(d->ldmGreeter);
+}
+
 bool Greeter::lockHint() const
 {
     Q_D(const Greeter);
