@@ -49,21 +49,19 @@ struct DisplayPrivate
     /* TRUE if a manual login option should be shown */
     gboolean greeter_show_manual_login;
 
+    /* TRUE if a remote login option should be shown */
+    gboolean greeter_show_remote_login;
+
     /* TRUE if the greeter is a lock screen */
     gboolean greeter_is_lock;
 
     /* Session requested to log into */
+    SessionType user_session_type;
     gchar *user_session;
 
     /* Program to run sessions through */
     gchar *session_wrapper;
 
-    /* PAM service to authenticate against */
-    gchar *pam_service;
-
-    /* PAM service to authenticate against for automatic logins */
-    gchar *pam_autologin_service;
-  
     /* TRUE if in a user session */
     gboolean in_user_session;
 
@@ -101,6 +99,11 @@ struct DisplayPrivate
     gboolean stopped;
 };
 
+/* PAM services to use */
+#define GREETER_SERVICE   "lightdm-greeter"
+#define USER_SERVICE      "lightdm"
+#define AUTOLOGIN_SERVICE "lightdm-autologin"
+
 G_DEFINE_TYPE (Display, display, G_TYPE_OBJECT);
 
 static void greeter_session_stopped_cb (Session *session, Display *display);
@@ -204,6 +207,13 @@ display_set_show_manual_login_hint (Display *display, gboolean show_manual_login
     display->priv->greeter_show_manual_login = show_manual_login;
 }
 
+void
+display_set_show_remote_login_hint (Display *display, gboolean show_remote_login)
+{
+    g_return_if_fail (display != NULL);
+    display->priv->greeter_show_remote_login = show_remote_login;
+}
+
 void
 display_set_lock_hint (Display *display, gboolean is_lock)
 {
@@ -212,10 +222,11 @@ display_set_lock_hint (Display *display, gboolean is_lock)
 }
 
 void
-display_set_user_session (Display *display, const gchar *session_name)
+display_set_user_session (Display *display, SessionType type, const gchar *session_name)
 {
     g_return_if_fail (display != NULL);
     g_free (display->priv->user_session);
+    display->priv->user_session_type = type;
     display->priv->user_session = g_strdup (session_name);
 }
 
@@ -341,7 +352,7 @@ greeter_start_authentication_cb (Greeter *greeter, const gchar *username, Displa
 }
 
 static gboolean
-greeter_start_session_cb (Greeter *greeter, const gchar *session_name, Display *display)
+greeter_start_session_cb (Greeter *greeter, SessionType type, const gchar *session_name, Display *display)
 {
     /* If no session requested, use the previous one */
     if (!session_name && !greeter_get_guest_authenticated (greeter))
@@ -349,6 +360,7 @@ greeter_start_session_cb (Greeter *greeter, const gchar *session_name, Display *
         User *user;
 
         user = session_get_user (greeter_get_authentication_session (greeter));
+        type = SESSION_TYPE_LOCAL;
         session_name = user_get_xsession (user);
     }
 
@@ -356,7 +368,7 @@ greeter_start_session_cb (Greeter *greeter, const gchar *session_name, Display *
     if (session_name)
     {
         g_debug ("Using session %s", session_name);
-        display_set_user_session (display, session_name);
+        display_set_user_session (display, type, session_name);
     }
 
     /* Stop this display if that session already exists and can switch to it */
@@ -393,7 +405,7 @@ start_greeter (Display *display)
     g_signal_connect (display->priv->session, "authentication-complete", G_CALLBACK (greeter_authentication_complete_cb), display);
 
     /* Make communication link to greeter that will run on this session */
-    display->priv->greeter = greeter_new (display->priv->session, display->priv->pam_service, display->priv->pam_autologin_service);
+    display->priv->greeter = greeter_new (display->priv->session, USER_SERVICE, AUTOLOGIN_SERVICE);
     g_signal_connect (G_OBJECT (display->priv->greeter), "connected", G_CALLBACK (greeter_connected_cb), display);
     g_signal_connect (G_OBJECT (display->priv->greeter), "start-authentication", G_CALLBACK (greeter_start_authentication_cb), display);
     g_signal_connect (G_OBJECT (display->priv->greeter), "start-session", G_CALLBACK (greeter_start_session_cb), display);
@@ -416,6 +428,7 @@ start_greeter (Display *display)
     greeter_set_hint (display->priv->greeter, "has-guest-account", (display->priv->allow_guest && display->priv->greeter_allow_guest) ? "true" : "false");
     greeter_set_hint (display->priv->greeter, "hide-users", display->priv->greeter_hide_users ? "true" : "false");
     greeter_set_hint (display->priv->greeter, "show-manual-login", display->priv->greeter_show_manual_login ? "true" : "false");
+    greeter_set_hint (display->priv->greeter, "show-remote-login", display->priv->greeter_show_remote_login ? "true" : "false");
     if (display->priv->greeter_is_lock)
         greeter_set_hint (display->priv->greeter, "lock-screen", "true");
 
@@ -439,7 +452,7 @@ start_greeter (Display *display)
     }
 
     g_signal_connect_after (display->priv->session, "stopped", G_CALLBACK (greeter_session_stopped_cb), display);
-    result = greeter_start (display->priv->greeter, display->priv->pam_service, greeter_user);
+    result = greeter_start (display->priv->greeter, GREETER_SERVICE, greeter_user);
     g_free (greeter_user);
 
     if (!result)
@@ -466,7 +479,7 @@ autologin_authentication_complete_cb (Session *session, Display *display)
         if (session_name)
         {
             g_debug ("Autologin using session %s", session_name);
-            display_set_user_session (display, session_name);
+            display_set_user_session (display, SESSION_TYPE_LOCAL, session_name);
         }
 
         g_signal_emit (display, signals[START_SESSION], 0, &result);
@@ -485,7 +498,7 @@ autologin_authentication_complete_cb (Session *session, Display *display)
 }
 
 static gboolean
-autologin (Display *display, const gchar *username, const gchar *service, gboolean start_greeter_if_fail)
+autologin (Display *display, const gchar *username, const gchar *service, gboolean start_greeter_if_fail, gboolean is_guest)
 {
     display->priv->start_greeter_if_fail = start_greeter_if_fail;
 
@@ -494,7 +507,7 @@ autologin (Display *display, const gchar *username, const gchar *service, gboole
     display->priv->session = create_session (display);
     g_signal_connect (display->priv->session, "authentication-complete", G_CALLBACK (autologin_authentication_complete_cb), display);
     g_signal_connect_after (display->priv->session, "stopped", G_CALLBACK (user_session_stopped_cb), display);
-    return session_start (display->priv->session, service, username, TRUE, FALSE);
+    return session_start (display->priv->session, service, username, TRUE, FALSE, is_guest);
 }
 
 static gboolean
@@ -510,7 +523,7 @@ autologin_guest (Display *display, const gchar *service, gboolean start_greeter_
         return FALSE;
     }
 
-    result = autologin (display, username, service, start_greeter_if_fail);
+    result = autologin (display, username, service, start_greeter_if_fail, TRUE);
     g_free (username);
 
     return result;
@@ -596,7 +609,7 @@ greeter_session_stopped_cb (Session *session, Display *display)
     {
         /* If guest, then start a new autologin guest session (so can setup account) */
         if (greeter_get_guest_authenticated (display->priv->greeter))
-            result = autologin_guest (display, display->priv->pam_autologin_service, FALSE);
+            result = autologin_guest (display, AUTOLOGIN_SERVICE, FALSE);
         /* Otherwise, use the session the greeter has authenticated */
         else
         {
@@ -692,12 +705,16 @@ display_start_session (Display *display)
 
     user = session_get_user (display->priv->session);
 
-    /* Store this session name so we automatically use it next time */
-    user_set_xsession (user, display->priv->user_session);
-
     /* Find the command to run for the selected session */
-    // FIXME: This is X specific, move into xsession.c
-    sessions_dir = config_get_string (config_get_instance (), "LightDM", "xsessions-directory");
+    if (display->priv->user_session_type == SESSION_TYPE_LOCAL)
+    {
+        sessions_dir = config_get_string (config_get_instance (), "LightDM", "xsessions-directory");
+
+        /* Store this session name so we automatically use it next time */
+        user_set_xsession (user, display->priv->user_session);
+    }
+    else
+        sessions_dir = config_get_string (config_get_instance (), "LightDM", "remote-sessions-directory");
     filename = g_strdup_printf ("%s.desktop", display->priv->user_session);
     path = g_build_filename (sessions_dir, filename, NULL);
     g_free (sessions_dir);
@@ -764,17 +781,17 @@ display_server_ready_cb (DisplayServer *display_server, Display *display)
     if (display->priv->autologin_timeout == 0 && display->priv->autologin_guest)
     {
         g_debug ("Automatically logging in as guest");
-        result = autologin_guest (display, display->priv->pam_autologin_service, TRUE);
+        result = autologin_guest (display, AUTOLOGIN_SERVICE, TRUE);
     }
     else if (display->priv->autologin_timeout == 0 && display->priv->autologin_user)
     {
         g_debug ("Automatically logging in user %s", display->priv->autologin_user);
-        result = autologin (display, display->priv->autologin_user, display->priv->pam_autologin_service, TRUE);
+        result = autologin (display, display->priv->autologin_user, AUTOLOGIN_SERVICE, TRUE, FALSE);
     }
     else if (display->priv->select_user_hint)
     {
         g_debug ("Logging in user %s", display->priv->select_user_hint);
-        result = autologin (display, display->priv->select_user_hint, display->priv->pam_service, TRUE);
+        result = autologin (display, display->priv->select_user_hint, USER_SERVICE, TRUE, FALSE);
     }
 
     /* If no session started, start a greeter */
@@ -900,8 +917,6 @@ static void
 display_init (Display *display)
 {
     display->priv = G_TYPE_INSTANCE_GET_PRIVATE (display, DISPLAY_TYPE, DisplayPrivate);
-    display->priv->pam_service = g_strdup ("lightdm");
-    display->priv->pam_autologin_service = g_strdup ("lightdm-autologin");
 }
 
 static void
@@ -923,8 +938,6 @@ display_finalize (GObject *object)
         g_object_unref (self->priv->greeter);
     }
     g_free (self->priv->session_wrapper);
-    g_free (self->priv->pam_service);
-    g_free (self->priv->pam_autologin_service);
     if (self->priv->session)
     {
         g_signal_handlers_disconnect_matched (self->priv->session, G_SIGNAL_MATCH_DATA, 0, 0, NULL, NULL, self);      
