@@ -19,6 +19,7 @@
 #include <unistd.h>
 #include <fcntl.h>
 #include <sys/stat.h>
+#include <sys/mman.h>
 
 #include "configuration.h"
 #include "display-manager.h"
@@ -816,6 +817,7 @@ main (int argc, char **argv)
     gboolean test_mode = FALSE;
     gchar *pid_path = "/var/run/lightdm.pid";
     gchar *xsessions_dir = NULL;
+    gchar *remote_sessions_dir = NULL;
     gchar *xgreeters_dir = NULL;
     gchar *config_dir;
     gchar *log_dir = NULL;
@@ -842,6 +844,9 @@ main (int argc, char **argv)
         { "xsessions-dir", 0, 0, G_OPTION_ARG_STRING, &xsessions_dir,
           /* Help string for command line --xsessions-dir flag */
           N_("Directory to load X sessions from"), "DIRECTORY" },
+        { "remote-sessions-dir", 0, 0, G_OPTION_ARG_STRING, &remote_sessions_dir,
+          /* Help string for command line --remote-sessions-dir flag */
+          N_("Directory to load remote sessions from"), "DIRECTORY" },
         { "xgreeters-dir", 0, 0, G_OPTION_ARG_STRING, &xgreeters_dir,
           /* Help string for command line --xgreeters-dir flag */
           N_("Directory to load X greeters from"), "DIRECTORY" },
@@ -951,6 +956,7 @@ main (int argc, char **argv)
 
     /* Always use absolute directories as child processes may run from different locations */
     xsessions_dir = path_make_absolute (xsessions_dir);
+    remote_sessions_dir = path_make_absolute (remote_sessions_dir);
     xgreeters_dir = path_make_absolute (xgreeters_dir);
 
     /* If not running as root write output to directories we control */
@@ -989,6 +995,8 @@ main (int argc, char **argv)
         config_set_string (config_get_instance (), "LightDM", "guest-account-script", "guest-account");
     if (!config_has_key (config_get_instance (), "LightDM", "greeter-user"))
         config_set_string (config_get_instance (), "LightDM", "greeter-user", GREETER_USER);
+    if (!config_has_key (config_get_instance (), "LightDM", "lock-memory"))
+        config_set_boolean (config_get_instance (), "LightDM", "lock-memory", TRUE);
     if (!config_has_key (config_get_instance (), "SeatDefaults", "type"))
         config_set_string (config_get_instance (), "SeatDefaults", "type", "xlocal");
     if (!config_has_key (config_get_instance (), "SeatDefaults", "xserver-command"))
@@ -999,6 +1007,8 @@ main (int argc, char **argv)
         config_set_boolean (config_get_instance (), "SeatDefaults", "allow-guest", TRUE);
     if (!config_has_key (config_get_instance (), "SeatDefaults", "greeter-allow-guest"))
         config_set_boolean (config_get_instance (), "SeatDefaults", "greeter-allow-guest", TRUE);
+    if (!config_has_key (config_get_instance (), "SeatDefaults", "greeter-show-remote-login"))
+        config_set_boolean (config_get_instance (), "SeatDefaults", "greeter-show-remote-login", TRUE);
     if (!config_has_key (config_get_instance (), "SeatDefaults", "greeter-session"))
         config_set_string (config_get_instance (), "SeatDefaults", "greeter-session", GREETER_SESSION);
     if (!config_has_key (config_get_instance (), "SeatDefaults", "user-session"))
@@ -1016,6 +1026,8 @@ main (int argc, char **argv)
     g_free (default_cache_dir);
     if (!config_has_key (config_get_instance (), "LightDM", "xsessions-directory"))
         config_set_string (config_get_instance (), "LightDM", "xsessions-directory", XSESSIONS_DIR);
+    if (!config_has_key (config_get_instance (), "LightDM", "remote-sessions-directory"))
+        config_set_string (config_get_instance (), "LightDM", "remote-sessions-directory", REMOTE_SESSIONS_DIR);
     if (!config_has_key (config_get_instance (), "LightDM", "xgreeters-directory"))
         config_set_string (config_get_instance (), "LightDM", "xgreeters-directory", XGREETERS_DIR);
 
@@ -1032,6 +1044,9 @@ main (int argc, char **argv)
     if (xsessions_dir)
         config_set_string (config_get_instance (), "LightDM", "xsessions-directory", xsessions_dir);
     g_free (xsessions_dir);
+    if (remote_sessions_dir)
+        config_set_string (config_get_instance (), "LightDM", "remote-sessions-directory", remote_sessions_dir);
+    g_free (remote_sessions_dir);
     if (xgreeters_dir)
         config_set_string (config_get_instance (), "LightDM", "xgreeters-directory", xgreeters_dir);
     g_free (xgreeters_dir);
@@ -1064,6 +1079,12 @@ main (int argc, char **argv)
                              NULL,
                              NULL);
 
+    if (config_get_boolean (config_get_instance (), "LightDM", "lock-memory"))
+    {
+        /* Protect memory from being paged to disk, as we deal with passwords */
+        mlockall (MCL_CURRENT | MCL_FUTURE);
+    }
+
     if (getuid () != 0)
         g_debug ("Running in user mode");
     if (getenv ("DISPLAY"))
