@@ -390,7 +390,6 @@ session_stopped_cb (Session *session, Seat *seat)
 
     if (seat->priv->guest_username && strcmp (session_get_username (session), seat->priv->guest_username) == 0)
     {
-        guest_account_cleanup (seat->priv->guest_username);
         g_free (seat->priv->guest_username);
         seat->priv->guest_username = NULL;
     }
@@ -486,6 +485,7 @@ switch_to_user_or_start_greeter (Seat *seat, const gchar *username, gboolean use
     display_set_session_wrapper (display, seat_get_string_property (seat, "session-wrapper"));
     display_set_hide_users_hint (display, seat_get_boolean_property (seat, "greeter-hide-users"));
     display_set_show_manual_login_hint (display, seat_get_boolean_property (seat, "greeter-show-manual-login"));
+    display_set_show_remote_login_hint (display, seat_get_boolean_property (seat, "greeter-show-remote-login"));
     if (is_lock)
         display_set_lock_hint (display, TRUE);
     display_set_allow_guest (display, seat_get_allow_guest (seat));
@@ -496,7 +496,7 @@ switch_to_user_or_start_greeter (Seat *seat, const gchar *username, gboolean use
         display_set_select_user_hint (display, username, is_guest);
     if (!session_name)
         session_name = seat_get_string_property (seat, "user-session");
-    display_set_user_session (display, session_name);
+    display_set_user_session (display, SESSION_TYPE_LOCAL, session_name);
 
     seat->priv->displays = g_list_append (seat->priv->displays, display);
     g_signal_emit (seat, signals[DISPLAY_ADDED], 0, display);
