@@ -256,11 +256,15 @@ session_child_run (int argc, char **argv)
     }
     if (xdisplay)
     {
+#ifdef PAM_XDISPLAY
         pam_set_item (pam_handle, PAM_XDISPLAY, xdisplay);
+#endif
         pam_set_item (pam_handle, PAM_TTY, xdisplay);
     }
     else if (tty)
         pam_set_item (pam_handle, PAM_TTY, tty);    
+
+#ifdef PAM_XAUTHDATA
     if (xauthority)
     {
         struct pam_xauth_data value;
@@ -271,6 +275,7 @@ session_child_run (int argc, char **argv)
         value.datalen = xauth_get_authorization_data_length (xauthority);
         pam_set_item (pam_handle, PAM_XAUTHDATA, &value);
     }
+#endif
 
     /* Authenticate */
     if (do_authenticate)
@@ -535,7 +540,9 @@ session_child_run (int argc, char **argv)
             strncpy (ut.ut_line, tty + strlen ("/dev/"), sizeof (ut.ut_line));
             strncpy (ut.ut_id, xdisplay, sizeof (ut.ut_id));
             strncpy (ut.ut_user, username, sizeof (ut.ut_user));
-            if (remote_host_name)
+            if (xdisplay)
+                strncpy (ut.ut_host, xdisplay, sizeof (ut.ut_host));
+            else if (remote_host_name)
                 strncpy (ut.ut_host, remote_host_name, sizeof (ut.ut_host));
             gettimeofday (&tv, NULL);
             ut.ut_tv.tv_sec = tv.tv_sec;
@@ -562,12 +569,14 @@ session_child_run (int argc, char **argv)
             strncpy (ut.ut_line, tty + strlen ("/dev/"), sizeof (ut.ut_line));
             strncpy (ut.ut_id, xdisplay, sizeof (ut.ut_id));
             strncpy (ut.ut_user, username, sizeof (ut.ut_user));
-            if (remote_host_name)
+            if (xdisplay)
+                strncpy (ut.ut_host, xdisplay, sizeof (ut.ut_host));
+            else if (remote_host_name)
                 strncpy (ut.ut_host, remote_host_name, sizeof (ut.ut_host));
             gettimeofday (&tv, NULL);
             ut.ut_tv.tv_sec = tv.tv_sec;
             ut.ut_tv.tv_usec = tv.tv_usec;
-    
+
             setutxent ();
             if (!pututxline (&ut))
                 g_printerr ("Failed to write utmpx: %s\n", strerror (errno));
