@@ -488,11 +488,10 @@ xserver_local_start (DisplayServer *display_server)
     }
 
     /* Variable required for regression tests */
-    if (g_getenv ("LIGHTDM_TEST_STATUS_SOCKET"))
+    if (g_getenv ("LIGHTDM_TEST_ROOT"))
     {
-        process_set_env (server->priv->xserver_process, "LIGHTDM_TEST_STATUS_SOCKET", g_getenv ("LIGHTDM_TEST_STATUS_SOCKET"));
-        process_set_env (server->priv->xserver_process, "LIGHTDM_TEST_CONFIG", g_getenv ("LIGHTDM_TEST_CONFIG"));
-        process_set_env (server->priv->xserver_process, "LIGHTDM_TEST_HOME_DIR", g_getenv ("LIGHTDM_TEST_HOME_DIR"));
+        process_set_env (server->priv->xserver_process, "LIGHTDM_TEST_ROOT", g_getenv ("LIGHTDM_TEST_ROOT"));
+        process_set_env (server->priv->xserver_process, "LD_PRELOAD", g_getenv ("LD_PRELOAD"));
         process_set_env (server->priv->xserver_process, "LD_LIBRARY_PATH", g_getenv ("LD_LIBRARY_PATH"));
     }
 
@@ -513,6 +512,12 @@ xserver_local_stop (DisplayServer *server)
     process_stop (XSERVER_LOCAL (server)->priv->xserver_process);
 }
 
+static gboolean
+xserver_local_get_is_stopped (DisplayServer *server)
+{
+    return process_get_pid (XSERVER_LOCAL (server)->priv->xserver_process) == 0;
+}
+
 static void
 xserver_local_init (XServerLocal *server)
 {
@@ -552,6 +557,7 @@ xserver_local_class_init (XServerLocalClass *klass)
 
     display_server_class->start = xserver_local_start;
     display_server_class->stop = xserver_local_stop;
+    display_server_class->get_is_stopped = xserver_local_get_is_stopped;
     object_class->finalize = xserver_local_finalize;
 
     g_type_class_add_private (klass, sizeof (XServerLocalPrivate));
