@@ -265,11 +265,9 @@ xserver_xvnc_start (DisplayServer *display_server)
     g_debug ("Launching Xvnc server");
 
     /* Variable required for regression tests */
-    if (g_getenv ("LIGHTDM_TEST_STATUS_SOCKET"))
+    if (g_getenv ("LIGHTDM_TEST_ROOT"))
     {
-        process_set_env (server->priv->xserver_process, "LIGHTDM_TEST_STATUS_SOCKET", g_getenv ("LIGHTDM_TEST_STATUS_SOCKET"));
-        process_set_env (server->priv->xserver_process, "LIGHTDM_TEST_CONFIG", g_getenv ("LIGHTDM_TEST_CONFIG"));
-        process_set_env (server->priv->xserver_process, "LIGHTDM_TEST_HOME_DIR", g_getenv ("LIGHTDM_TEST_HOME_DIR"));
+        process_set_env (server->priv->xserver_process, "LIGHTDM_TEST_ROOT", g_getenv ("LIGHTDM_TEST_ROOT"));
         process_set_env (server->priv->xserver_process, "LD_LIBRARY_PATH", g_getenv ("LD_LIBRARY_PATH"));
     }
 
@@ -290,6 +288,12 @@ xserver_xvnc_stop (DisplayServer *server)
     process_stop (XSERVER_XVNC (server)->priv->xserver_process);
 }
 
+static gboolean
+xserver_xvnc_get_is_stopped (DisplayServer *server)
+{
+    return process_get_pid (XSERVER_XVNC (server)->priv->xserver_process) == 0;
+}
+
 static void
 xserver_xvnc_init (XServerXVNC *server)
 {
@@ -323,6 +327,7 @@ xserver_xvnc_class_init (XServerXVNCClass *klass)
 
     display_server_class->start = xserver_xvnc_start;
     display_server_class->stop = xserver_xvnc_stop;
+    display_server_class->get_is_stopped = xserver_xvnc_get_is_stopped;
     object_class->finalize = xserver_xvnc_finalize;
 
     g_type_class_add_private (klass, sizeof (XServerXVNCPrivate));
