@@ -1,16 +1,25 @@
 #include <stdlib.h>
 #include <glib.h>
+#include <glib-object.h>
 
 #include "status.h"
 
 static GKeyFile *config;
 
+static void
+request_cb (const gchar *message)
+{
+}
+
 int
 main (int argc, char **argv)
 {
+    g_type_init ();
+
+    status_connect (request_cb);
+
     config = g_key_file_new ();
-    if (g_getenv ("LIGHTDM_TEST_CONFIG"))
-        g_key_file_load_from_file (config, g_getenv ("LIGHTDM_TEST_CONFIG"), G_KEY_FILE_NONE, NULL);
+    g_key_file_load_from_file (config, g_build_filename (g_getenv ("LIGHTDM_TEST_ROOT"), "script", NULL), G_KEY_FILE_NONE, NULL);
   
     if (argc < 2)
     {
@@ -18,7 +27,7 @@ main (int argc, char **argv)
         return EXIT_FAILURE;
     }
 
-    notify_status ("SCRIPT-HOOK %s", argv[1]);
+    status_notify ("SCRIPT-HOOK %s", argv[1]);
 
     if (argc > 2)
         return atoi (argv[2]);
