@@ -25,6 +25,7 @@
 #define AUTOLOGIN_KEY_NAME  "autologin-user"
 #define HIDE_USERS_KEY_NAME  "greeter-hide-users"
 #define MANUAL_LOGIN_KEY_NAME  "greeter-show-manual-login"
+#define REMOTE_LOGIN_KEY_NAME  "greeter-show-remote-login"
 #define ALLOW_GUEST_KEY_NAME  "allow-guest"
 
 #define IS_STRING_EMPTY(x) ((x)==NULL||(x)[0]=='\0')
@@ -34,6 +35,7 @@ static gboolean keep_old = FALSE;
 static gboolean remove = FALSE;
 static gboolean hide_users = FALSE;
 static gboolean show_manual_login = FALSE;
+static gboolean show_remote_login = FALSE;
 static gboolean allow_guest = FALSE;
 
 static char    *session = NULL;
@@ -41,6 +43,7 @@ static char    *greeter = NULL;
 static char    *autologin = NULL;
 static char    *str_hide_users = NULL;
 static char    *str_show_manual_login = NULL;
+static char    *str_show_remote_login = NULL;
 static char    *str_allow_guest = NULL;
 
 static GOptionEntry entries[] =
@@ -53,6 +56,7 @@ static GOptionEntry entries[] =
   { "autologin",'a', 0, G_OPTION_ARG_STRING, &autologin, N_("Set autologin user"), NULL },
   { "hide-users",'i', 0, G_OPTION_ARG_STRING, &str_hide_users, N_("Set greeter-hide-users to true or false"), NULL },
   { "show-manual-login",'m', 0, G_OPTION_ARG_STRING, &str_show_manual_login, N_("Set show-manual-login to true or false"), NULL },
+  { "show-remote-login",'R', 0, G_OPTION_ARG_STRING, &str_show_remote_login, N_("Set show-remote-login to true or false"), NULL },
   { "allow-guest",'l', 0, G_OPTION_ARG_STRING, &str_allow_guest, N_("Set allow-guest to true or false"), NULL },
   { NULL }
 };
@@ -175,7 +179,7 @@ main (int argc, char *argv[])
         g_error_free (error);
         return 1;
     }
-    if (IS_STRING_EMPTY (session) && IS_STRING_EMPTY (greeter) && IS_STRING_EMPTY (autologin) && IS_STRING_EMPTY(str_hide_users) && IS_STRING_EMPTY(str_show_manual_login) && IS_STRING_EMPTY(str_allow_guest)) {
+    if (IS_STRING_EMPTY (session) && IS_STRING_EMPTY (greeter) && IS_STRING_EMPTY (autologin) && IS_STRING_EMPTY(str_hide_users) && IS_STRING_EMPTY(str_show_manual_login) && IS_STRING_EMPTY(str_show_remote_login) && IS_STRING_EMPTY(str_allow_guest)) {
         g_printerr (N_("Wrong usage of the command\n%s"), g_option_context_get_help (context, FALSE, NULL));
         g_option_context_free (context);
         return 1;
@@ -231,6 +235,15 @@ main (int argc, char *argv[])
             return 1;
         }
     }
+    if (!(IS_STRING_EMPTY(str_show_remote_login)) && (return_code == 0)) {
+        if (str_to_bool(str_show_remote_login, &show_remote_login) == 0) {
+            return_code = update_boolean (show_remote_login, keep_old, SEATDEFAULT_KEY_GROUP, REMOTE_LOGIN_KEY_NAME, keyfile);
+        }
+        else {
+            g_printerr (N_("true and false are the only valid choices for show-remote-login\n"));
+            return 1;
+        }
+    }
 
     if (return_code == 0) {
         s_data = g_key_file_to_data (keyfile, &size, &error);
